#!/usr/bin/env python

"""
===============================================================
Information about release and authors
===============================================================
"""

__author__ = """
                Diana Zaiceva <zaiceva@cs.karelia.ru>,
                Mezhenin Artoym <mezhenin@cs.karelia.ru>,
                Alexander Sannikov <sannikov@cs.karelia.ru>,
                Kirill Germanov <kgermano@cs.karelia.ru>
             """
__version__ = "0.3.1"
__date__ = "$Date: 2010/11/04 $"
__copyright__ = ""
__license__ = "GPLv2"
